exceptiontools.TypographicWhitespaceError
=========================================

.. inheritance-diagram:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.TypographicWhitespaceError.TypographicWhitespaceError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
